# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`rbac`](#rbac): A simple RBAC implementation for managing users

### Defined types

#### Public Defined types

* [`rbac::group`](#rbacgroup): Grants membership of a posix group based on roles.
* [`rbac::ssh`](#rbacssh): Grants ssh access based on roles.
* [`rbac::user`](#rbacuser): Creates users based on their role

#### Private Defined types

* `rbac::sshto`: Grants ssh access based on roles.

## Classes

### `rbac`

This class ensures that any user in the provided userlist who has
not been granted access on the system through one of this module's
defined types is purged from the system.

#### Examples

##### 

```puppet
include rbac
```

#### Parameters

The following parameters are available in the `rbac` class.

##### `users`

Data type: `Hash`

A hash with user data

##### `roles`

Data type: `Hash`

A hash with roles and lists of users having said role

## Defined types

### `rbac::group`

Calling rbac::group will ensure that every user with the given role, as well
as any user in the additional_members array, and only these users, will be
members of the given group.

#### Examples

##### 

```puppet
rbac::group { 'foo':
  group => 'foo',
  role  => 'myrole'
}
```

#### Parameters

The following parameters are available in the `rbac::group` defined type.

##### `group`

Data type: `String`

The group users with the specified role will be member of.

##### `role`

Data type: `Optional[String]`

The role users must have to be member of the given group.

Default value: ``undef``

##### `additional_members`

Data type: `Array[String]`

Additional users that should be member of the given group, but do not have
the specified role.

Default value: `[]`

### `rbac::ssh`

Calling rbac::ssh will ensure that the ssh keys of everyone in the
rbac::users hash with the appropriate role will be part of to the
authorized_keys for the given user.

#### Examples

##### 

```puppet
rbac::ssh { 'foo':
  user => 'bar',
  role => 'myrole'
}
```

#### Parameters

The following parameters are available in the `rbac::ssh` defined type.

##### `user`

Data type: `String`

The user to which ssh access will be granted.

##### `role`

Data type: `String`

The role users must have to have ssh access to the given user.

##### `options`

Data type: `Array`

An array with key options; see sshd(8) for possible values

Default value: `[]`

### `rbac::user`

Calling rbac::user will ensure that every user in the rbac::users hash
with the given role will be present on the system and accessible using
the provided ssh keys.

#### Examples

##### 

```puppet
rbac::user { 'myrole': }
```

#### Parameters

The following parameters are available in the `rbac::user` defined type.

##### `role`

Data type: `String`

The role users must have to be present and have access to this system.

Default value: `$title`

##### `ssh`

Data type: `Boolean`

Whether or not ssh access should be managed by rbac

Default value: ``true``

##### `mailalias`

Data type: `Boolean`

Whether or not mailaliases should be managed by rbac

Default value: ``true``

